@@ -24,14 +24,16 @@ def run(user_params, api_params):
     params = {**user_params["params"], **api_params}
     logger.info("combined params: " + str(params))
 
-    pre_func = None
-    if "pre" in user_params:
-        pre_func = user_params["pre"]
+    # pre_func = None
+    # if "pre" in user_params:
+    #     pre_func = user_params["pre"]
 
     if "model" in user_params and user_params["model"]:
         data_in = [
-            Data(dataname, source, params, pre_func).data
-            for dataname, source in user_params["model"]
+            Data(
+                dataname, source, params, prefunc[0] if len(prefunc) > 0 else None
+            ).data
+            for dataname, source, *prefunc in user_params["model"]
         ]
     else:
         data_in = None
